==> ejc-jltest-impl-3.0.0-20240311.091845-55-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlanaEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
/**
 * 安措费使用计划A
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_plana")
public class PlanaEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 安全生产会议发文字号
    @TableField(value="plana_name")
    private String planaName; // 安措费使用计划发文名称
    @TableField(value="plana_urgency")
    private Integer planaUrgency; // 紧急程度（1-特急，2-急，3-一般）
    @TableField(value="plana_secret")
    private Integer planaSecret; //  密级（1-公开，2-秘密，3-机密，4-绝密）
    @TableField(value="plana_date")
    private Date planaDate; // 安措费使用计划发文日期
    @TableField(value="plana_mny")
    private BigDecimal planaMny; // 拟投入金额
    @TableField(value="safeteama_id")
    private Long safeteamaId; // 安全小组主键
    @TableField(value="safeteama_name")
    private String safeteamaName; // 安全小组发文名称
    @TableField(value="safeteama_bill_code")
    private String safeteamaBillCode; // 安全小组成立发文字号
    @TableField(value="safeteama_date")
    private Date safeteamaDate; // 安全小组发文日期
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="memo")
    private String memo; // 安措费使用计发文说明
    @TableField(value="submit_people_id")
    private Long submitPeopleId; // 提交人
    @TableField(value="submit_people_name")
    private String submitPeopleName; // 提交人名称
    @TableField(value="submit_date")
    private Date submitDate; // 提交日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="planaDetailService",pidName = "planaId")
    private List<PlanaDetailEntity> planaDetailList = new ArrayList<>(); // 安措费使用计划明细A
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getPlanaName() {
        return planaName;
    }

    public void setPlanaName(String planaName) {
        this.planaName = planaName;
    }
    public Integer getPlanaUrgency() {
        return planaUrgency;
    }

    public void setPlanaUrgency(Integer planaUrgency) {
        this.planaUrgency = planaUrgency;
    }
    public Integer getPlanaSecret() {
        return planaSecret;
    }

    public void setPlanaSecret(Integer planaSecret) {
        this.planaSecret = planaSecret;
    }
    public Date getPlanaDate() {
        return planaDate;
    }

    public void setPlanaDate(Date planaDate) {
        this.planaDate = planaDate;
    }
    public BigDecimal getPlanaMny() {
        return planaMny;
    }

    public void setPlanaMny(BigDecimal planaMny) {
        this.planaMny = planaMny;
    }
    public Long getSafeteamaId() {
        return safeteamaId;
    }

    public void setSafeteamaId(Long safeteamaId) {
        this.safeteamaId = safeteamaId;
    }
    public String getSafeteamaName() {
        return safeteamaName;
    }

    public void setSafeteamaName(String safeteamaName) {
        this.safeteamaName = safeteamaName;
    }
    public String getSafeteamaBillCode() {
        return safeteamaBillCode;
    }

    public void setSafeteamaBillCode(String safeteamaBillCode) {
        this.safeteamaBillCode = safeteamaBillCode;
    }
    public Date getSafeteamaDate() {
        return safeteamaDate;
    }

    public void setSafeteamaDate(Date safeteamaDate) {
        this.safeteamaDate = safeteamaDate;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSubmitPeopleId() {
        return submitPeopleId;
    }

    public void setSubmitPeopleId(Long submitPeopleId) {
        this.submitPeopleId = submitPeopleId;
    }
    public String getSubmitPeopleName() {
        return submitPeopleName;
    }

    public void setSubmitPeopleName(String submitPeopleName) {
        this.submitPeopleName = submitPeopleName;
    }
    public Date getSubmitDate() {
        return submitDate;
    }

    public void setSubmitDate(Date submitDate) {
        this.submitDate = submitDate;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    

    public List<PlanaDetailEntity> getPlanaDetailList() {
        return planaDetailList;
    }

    public void setPlanaDetailList(List<PlanaDetailEntity> planaDetailList) {
        this.planaDetailList = planaDetailList;
    }
}

==> ejc-jltest-impl-3.0.0-20240328.021343-126-sources.jar: com/ejianc/business/jltest/orgtest/bean/PlanaEntity.java <==
package com.ejianc.business.jltest.orgtest.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
/**
 * 安措费使用计划A
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_plana")
public class PlanaEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 安全生产会议发文字号
    @TableField(value="plana_name")
    private String planaName; // 安措费使用计划发文名称
    @TableField(value="plana_urgency")
    private Integer planaUrgency; // 紧急程度（1-特急，2-急，3-一般）
    @TableField(exist=false)
    private String urgencyName;
    @TableField(value="plana_secret")
    private Integer planaSecret; //  密级（1-公开，2-秘密，3-机密，4-绝密）
    @TableField(exist=false)
    private String secretName;
    @TableField(value="plana_date")
    private Date planaDate; // 安措费使用计划发文日期
    @TableField(value="plana_mny")
    private BigDecimal planaMny; // 拟投入金额
    @TableField(value="safeteama_id")
    private Long safeteamaId; // 安全小组主键
    @TableField(value="safeteama_name")
    private String safeteamaName; // 安全小组发文名称
    @TableField(value="safeteama_bill_code")
    private String safeteamaBillCode; // 安全小组成立发文字号
    @TableField(value="safeteama_date")
    private Date safeteamaDate; // 安全小组发文日期
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="memo")
    private String memo; // 安措费使用计发文说明
    @TableField(value="submit_people_id")
    private Long submitPeopleId; // 提交人
    @TableField(value="submit_people_name")
    private String submitPeopleName; // 提交人名称
    @TableField(value="submit_date")
    private Date submitDate; // 提交日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="planaDetailService",pidName = "planaId")
    private List<PlanaDetailEntity> planaDetailList = new ArrayList<>(); // 安措费使用计划明细A

    public String getUrgencyName() {
        return urgencyName;
    }

    public void setUrgencyName(String urgencyName) {
        this.urgencyName = urgencyName;
    }

    public String getSecretName() {
        return secretName;
    }

    public void setSecretName(String secretName) {
        this.secretName = secretName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getPlanaName() {
        return planaName;
    }

    public void setPlanaName(String planaName) {
        this.planaName = planaName;
    }
    public Integer getPlanaUrgency() {
        return planaUrgency;
    }

    public void setPlanaUrgency(Integer planaUrgency) {
        this.planaUrgency = planaUrgency;
    }
    public Integer getPlanaSecret() {
        return planaSecret;
    }

    public void setPlanaSecret(Integer planaSecret) {
        this.planaSecret = planaSecret;
    }
    public Date getPlanaDate() {
        return planaDate;
    }

    public void setPlanaDate(Date planaDate) {
        this.planaDate = planaDate;
    }
    public BigDecimal getPlanaMny() {
        return planaMny;
    }

    public void setPlanaMny(BigDecimal planaMny) {
        this.planaMny = planaMny;
    }
    public Long getSafeteamaId() {
        return safeteamaId;
    }

    public void setSafeteamaId(Long safeteamaId) {
        this.safeteamaId = safeteamaId;
    }
    public String getSafeteamaName() {
        return safeteamaName;
    }

    public void setSafeteamaName(String safeteamaName) {
        this.safeteamaName = safeteamaName;
    }
    public String getSafeteamaBillCode() {
        return safeteamaBillCode;
    }

    public void setSafeteamaBillCode(String safeteamaBillCode) {
        this.safeteamaBillCode = safeteamaBillCode;
    }
    public Date getSafeteamaDate() {
        return safeteamaDate;
    }

    public void setSafeteamaDate(Date safeteamaDate) {
        this.safeteamaDate = safeteamaDate;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSubmitPeopleId() {
        return submitPeopleId;
    }

    public void setSubmitPeopleId(Long submitPeopleId) {
        this.submitPeopleId = submitPeopleId;
    }
    public String getSubmitPeopleName() {
        return submitPeopleName;
    }

    public void setSubmitPeopleName(String submitPeopleName) {
        this.submitPeopleName = submitPeopleName;
    }
    public Date getSubmitDate() {
        return submitDate;
    }

    public void setSubmitDate(Date submitDate) {
        this.submitDate = submitDate;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    

    public List<PlanaDetailEntity> getPlanaDetailList() {
        return planaDetailList;
    }

    public void setPlanaDetailList(List<PlanaDetailEntity> planaDetailList) {
        this.planaDetailList = planaDetailList;
    }
}
